Tomography widgets
==================

Used for displaying or processing results [G1]_. 

Displaying
----------
A basic window capable of displaying a single reconstruction DiagGraphWindow. Can load a sequence of reconstructions and be synchronized with other windows. 

.. automodule:: tomotok.gui.widgets_tomo
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:


Processing
----------

.. automodule:: tomotok.gui.roi
    :members: GraphRectangles, GraphContours
    :undoc-members:
    :show-inheritance:
    :noindex:


.. automodule:: tomotok.gui.profiler
    :members: GraphProfiler
    :show-inheritance:
    :noindex:


.. automodule:: tomotok.gui.merfer
    :members: GraphMerfer
    :show-inheritance:
    :noindex:
